/**
 * TCS Dependency Map Renderer
 *
 * Copyright (c) 2005 TopCoder, Inc. All rights Reserved.
 */
package com.topcoder.rules.dependencymap.view.failuretests;

import java.awt.Color;
import java.awt.geom.GeneralPath;
import java.io.File;

import junit.framework.TestCase;

import com.topcoder.rules.dependencymap.view.Dependency;
import com.topcoder.rules.dependencymap.view.RendererGraphics;
import com.topcoder.rules.dependencymap.view.SVGRenderer;

/**
 * Failure test cases for FixedGridLayoutManager.
 *
 * @author AdamSelene
 */
public class SVGRendererTest extends TestCase {
	
	private File goodFile = new File(".");
	private SVGRenderer svgr = new SVGRenderer(goodFile);
	private RendererGraphics svgga = svgr.getGraphics(new Dependency("greg"));
	
    /**
     * Test constructor with null file.
     */
    public void testCon_Null() {
        try {
            new SVGRenderer(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

    /**
     * Test constructor.
     */
    public void testCon_Silent() {
    	new SVGRenderer(goodFile);
    }
    
    /**
     * Test set with null file.
     */
    public void testSet_Null() {
        try {
            svgr.setPath(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    }

    
    /**
     * Test set.
     */
    public void testSet_Silent() {
        svgr.setPath(goodFile);
    }
    
    /**
     * Test set color with null.
     */
    public void testSetColor()
    {
        try {
            svgga.setColor(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    	
    }

    /**
     * Test set color.
     */
    public void testSetColor_Silent()
    {
        svgga.setColor(Color.BLACK);
    }
    
    /**
     * Test set font with null.
     */
    public void testSetFont()
    {
        try {
            svgga.setFont(null);
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }
    	
    }
    
    /**
     * Test get font metrics with null.
     */
    public void testGetFontM()
    {
        try {
            svgga.getFontMetrics(null);            
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }    	
    }
    
    /**
     * Test draw with null.
     */
    public void testDraw()
    {
        try {
            svgga.draw(null);            
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }    	
    }

    /**
     * Test draw.
     */
    public void testDraw_Silent()
    {
        svgga.draw(new GeneralPath());            
    }

    
    /**
     * Test string with null.
     */
    public void testDrawS()
    {
        try {
            svgga.drawString(null,0,0);            
            fail("Should have thrown NullPointerException.");
        } catch (NullPointerException npe) { /* expected */ }    	
    }

    /**
     * Test draw string .
     */
    public void testDrawS_Silent()
    {
        svgga.drawString("test",0,0);            
    }

    /**
     * Test draw string .
     */
    public void testDrawS_Silent2()
    {
        svgga.drawString("test",-1,0);            
    }

    /**
     * Test draw string .
     */
    public void testDrawS_Silent3()
    {
        svgga.drawString("test",-20,-20);            
    }

}
